# data_file_writer_v4.R
# Patrick Applegate, patrick.applegate@psu.edu
# 
# Creates .csv files containing the temperature curves
# and modeled ice volumes for the geoengineering experiments.  

# Mise en place.  
rm(list = ls())
graphics.off()

# Set the working directory.  
# setwd('~/Documents/Work/geoengineering/code_figures/')

# Get some necessary scripts and packages.  
source('read_ser.R')
# require(signal)

# Set some values.  
geo_yr0 = seq(2025, 2475, 50)       # yr; vector of times when
                                    # geoengineering starts
run_tags = c('equil', '0.1grad')
                                    # flags indicating the type
                                    # of geoengineering scenario;
                                    # equil, temperatures level off
                                    # grad, temps decline gradually
hind_yr0 = 1840                     # year in which hindcast starts
hind_yr = c(1900, 2005)             # desired years from hindcast
proj_yr0 = 2005                     # year in which projections
                                    # begin
proj_yr = c(2006, 3000)             # years over which projection
                                    # model output is used
wdo_yr = c(-29, 500)                # years over which to subsample
                                    # the projection model output,
                                    # relative to the year values
                                    # in geo_yr0

# Step #1: Create matrices of important variables
# for the period 1900-2005, and write them to files.  
# Read in the relevant SICOPOLIS output file (contains
# both temperature forcings and simulated ice volumes).  
hind_data = read_ser('../output/grl10_6deg_100yr_lhs29/grl10_6deg_100yr_lhs29.ser')
# Set up matrices to hold information from the
# output file.  
hind_nrow = hind_yr[2]- hind_yr[1]+ 1
hind_T = matrix(NA, nrow = hind_nrow, ncol = 2, dimnames = list(NULL, c('Time_yr', 'T_anom_K')))
hind_V = matrix(NA, nrow = hind_nrow, ncol = 2, dimnames = list(NULL, c('Time_yr', 'iceVol_msle')))
hind_Vdot = matrix(NA, nrow = hind_nrow, ncol = 2, dimnames = list(NULL, c('Time_yr', 'iceVoldot_mmsle_yr')))
# Put the information from the output file into the matrices.  
# Multiply the time stamps (first column) by 10^3 to turn
# them into years instead of kyr.  Also multiply the rates
# of sea level change vector by 10^3 to turn m into mm.  
hind_row = hind_yr- hind_yr0+ 1
hind_T[, 1] = hind_data[hind_row[1]: hind_row[2], 1]* 10^3
hind_V[, 1] = hind_data[hind_row[1]: hind_row[2], 1]* 10^3
hind_Vdot[, 1] = hind_data[hind_row[1]: hind_row[2], 1]* 10^3
hind_T[, 2] = hind_data[hind_row[1]: hind_row[2], 2]
hind_V[, 2] = hind_data[hind_row[1]: hind_row[2], 9]
hind_Vdot[, 2] = (c(hind_data[hind_row[1]- 1, 9], hind_V[1: hind_nrow- 1, 2])- hind_V[, 2])* 10^3
# Make a simple plot as a check on the rates.  
# plot(hind_T[, 2], hind_Vdot[, 2], xlab = 'Temperature anomaly [K]', ylab = 'Rate of sea level contribution [mm/yr]')
# Write important matrices to files.  
write.csv(hind_T, '../data_tables/hindcast(1900_2005)_T.csv', row.names = FALSE)
write.csv(hind_V, '../data_tables/hindcast(1900_2005)_V.csv', row.names = FALSE)
write.csv(hind_Vdot, '../data_tables/hindcast(1900_2005)_Vdot.csv', row.names = FALSE)
# Delete large matrices to save memory.  
rm(hind_data)

# Step #2: As Step #1, but for the no-geoengineering,
# RCP8p5 scenario.  
# Read in the relevant SICOPOLIS output file (contains
# both temperature forcings and simulated ice volumes).  
rcp_data = read_ser('../output/grl10_rcp8p5_2005to3500_lhs29/grl10_rcp8p5_2005to3500_lhs29.ser')
# Set up matrices to hold information from the
# output file.  
proj_nrow = proj_yr[2]- proj_yr[1]+ 1
rcp_T = matrix(NA, nrow = proj_nrow, ncol = 2, dimnames = list(NULL, c('Time_yr', 'T_anom_K')))
rcp_V = matrix(NA, nrow = proj_nrow, ncol = 2, dimnames = list(NULL, c('Time_yr', 'iceVol_msle')))
rcp_Vdot = matrix(NA, nrow = proj_nrow, ncol = 2, dimnames = list(NULL, c('Time_yr', 'iceVoldot_mmsle_yr')))
# Put the information from the output file into the matrices.  
# Multiply the time stamps (first column) by 10^3 to turn
# them into years instead of kyr.  Also multiply the rates
# in the sea level change vector by 10^3 to turn m into mm.  
proj_row = proj_yr- proj_yr0+ 1
rcp_T[, 1] = rcp_data[proj_row[1]: proj_row[2], 1]* 10^3
rcp_V[, 1] = rcp_data[proj_row[1]: proj_row[2], 1]* 10^3
rcp_Vdot[, 1] = rcp_data[proj_row[1]: proj_row[2], 1]* 10^3
rcp_T[, 2] = rcp_data[proj_row[1]: proj_row[2], 2]
rcp_V[, 2] = rcp_data[proj_row[1]: proj_row[2], 9]
rcp_Vdot[, 2] = (c(hind_V[hind_nrow, 2], rcp_V[1: proj_nrow- 1, 2])- rcp_V[, 2])* 10^3
# Make a simple plot as a check on the rates.  
# plot(rcp_T[, 2], rcp_Vdot[, 2], xlab = 'Temperature anomaly [K]', ylab = 'Rate of sea level contribution [mm/yr]')
# Step 2b: Cut the time series of model inputs and outputs
# into "windows" that include the years in which
# geoengineering begins.  
# Set up matrices to store the windowed output
# from the base model run, following RCP 8.5.  
wdo_nrow = wdo_yr[2]- wdo_yr[1]+ 1
n_yr0 = length(geo_yr0)
wdo_rcp_T = matrix(NA, nrow = wdo_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('T_anom_K_geo_yr0_', as.character(geo_yr0), sep = ''))))
wdo_rcp_V = matrix(NA, nrow = wdo_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('iceVol_msle_geo_yr0_', as.character(geo_yr0), sep = ''))))
wdo_rcp_Vdot = matrix(NA, nrow = wdo_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('iceVoldot_mmsle_geo_yr0_', as.character(geo_yr0), sep = ''))))
# Populate the first columns of the window matrices with a time stamp.  
wdo_rcp_T[, 1] = seq(wdo_yr[1], wdo_yr[2], by = 1)
wdo_rcp_V[, 1] = seq(wdo_yr[1], wdo_yr[2], by = 1)
wdo_rcp_Vdot[, 1] = seq(wdo_yr[1], wdo_yr[2], by = 1)
# Step over the years in which geoengineering begins, placing
# the appropriate information from the rcp_* matrices into 
# the wdo_rcp_* matrices.  
for (i in 1: n_yr0) {
  wdo_rows = c(wdo_yr[1]- proj_yr[1]+ geo_yr0[i], wdo_yr[2]- proj_yr[1]+ geo_yr0[i])
    n_NAs = max(c(0, (1- wdo_rows[1])))
    wdo_rcp_T[(n_NAs+ 1): wdo_nrow, i+ 1] = rcp_T[(wdo_rows[1]+ n_NAs): wdo_rows[2], 2]
    wdo_rcp_V[(n_NAs+ 1): wdo_nrow, i+ 1] = rcp_V[(wdo_rows[1]+ n_NAs): wdo_rows[2], 2]
    wdo_rcp_Vdot[(n_NAs+ 1): wdo_nrow, i+ 1] = rcp_Vdot[(wdo_rows[1]+ n_NAs): wdo_rows[2], 2]
}

# Write the matrices to files.  
write.csv(rcp_T, '../data_tables/rcp8p5(2006_3000)_T.csv', row.names = FALSE)
write.csv(rcp_V, '../data_tables/rcp8p5(2006_3000)_V.csv', row.names = FALSE)
write.csv(rcp_Vdot, '../data_tables/rcp8p5(2006_3000)_Vdot.csv', row.names = FALSE)
write.csv(wdo_rcp_T, '../data_tables/window_rcp8p5_T.csv', row.names = FALSE)
write.csv(wdo_rcp_V, '../data_tables/window_rcp8p5_V.csv', row.names = FALSE)
write.csv(wdo_rcp_Vdot, '../data_tables/window_rcp8p5_Vdot.csv', row.names = FALSE)
# Delete large matrices to save memory.  
rm(rcp_data)

# Step #3: As Steps #1 and #2, but for the geoengineering
# scenarios.  Include the windowing, as described above.  
n_types = length(run_tags)
for (i in 1: n_types) {
  # Make some matrices to store the model output.  
  geo_T = matrix(NA, nrow = proj_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('T_anom_K_geo_yr0_', as.character(geo_yr0), sep = ''))))
  geo_V = matrix(NA, nrow = proj_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('iceVol_msle_geo_yr0_', as.character(geo_yr0), sep = ''))))
  geo_Vdot = matrix(NA, nrow = proj_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('iceVoldot_mmsle_geo_yr0_', as.character(geo_yr0), sep = ''))))
  wdo_geo_T = matrix(NA, nrow = wdo_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('T_anom_K_geo_yr0_', as.character(geo_yr0), sep = ''))))
  wdo_geo_V = matrix(NA, nrow = wdo_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('iceVol_msle_geo_yr0_', as.character(geo_yr0), sep = ''))))
  wdo_geo_Vdot = matrix(NA, nrow = wdo_nrow, ncol = n_yr0+ 1, dimnames = list(NULL, c('Time_yr', paste('iceVoldot_mmsle_geo_yr0_', as.character(geo_yr0), sep = ''))))
  for (j in 1: n_yr0) {
    # Read in the relevant SICOPOLIS output file (contains
    # both temperature forcings and simulated ice volumes).  
    geo_run = paste('grl10_rcp8p5_', run_tags[i], geo_yr0[j], '_lhs29', sep = '')
    geo_file = paste('../output/', geo_run, '/', geo_run, '.ser', sep = '')
    geo_data = read_ser(geo_file)
    # Put the information from the output file into the matrices.  
    geo_T[, j+ 1] = geo_data[proj_row[1]: proj_row[2], 2]
    geo_V[, j+ 1] = geo_data[proj_row[1]: proj_row[2], 9]
    geo_Vdot[, j+ 1] = (c(hind_V[hind_nrow, 2], geo_V[1: proj_nrow- 1, j+ 1])- geo_V[, j+ 1])* 10^3
    wdo_rows = c(wdo_yr[1]- proj_yr[1]+ geo_yr0[j], wdo_yr[2]- proj_yr[1]+ geo_yr0[j])
    n_NAs = max(c(0, (1- wdo_rows[1])))
    wdo_geo_T[(n_NAs+ 1): wdo_nrow, j+ 1] = geo_T[(wdo_rows[1]+ n_NAs): wdo_rows[2], j+ 1]
    wdo_geo_V[(n_NAs+ 1): wdo_nrow, j+ 1] = geo_V[(wdo_rows[1]+ n_NAs): wdo_rows[2], j+ 1]
    wdo_geo_Vdot[(n_NAs+ 1): wdo_nrow, j+ 1] = geo_Vdot[(wdo_rows[1]+ n_NAs): wdo_rows[2], j+ 1]
    # Make a simple plot as a check on the rates.  
    # plot(geo_T[, j+ 1], geo_Vdot[, j+ 1], main = geo_run, xlab = 'Temperature anomaly [K]', ylab = 'Rate of sea level contribution [mm/yr]')
  }
  # Add a time signal to the matrices.  
  geo_T[, 1] = geo_data[proj_row[1]: proj_row[2], 1]* 10^3
  geo_V[, 1] = geo_data[proj_row[1]: proj_row[2], 1]* 10^3
  geo_Vdot[, 1] = geo_data[proj_row[1]: proj_row[2], 1]* 10^3
  wdo_geo_T[, 1] = seq(wdo_yr[1], wdo_yr[2], by = 1)
  wdo_geo_V[, 1] = seq(wdo_yr[1], wdo_yr[2], by = 1)
  wdo_geo_Vdot[, 1] = seq(wdo_yr[1], wdo_yr[2], by = 1)
  # Make some plots to check the windowing.  
  pdf_file = paste('../data_tables/window_', run_tags[i], '.pdf', sep = '')
  pdf(pdf_file, width = 9, height = 5)
  par(mfrow = c(1, 3))
  matplot(wdo_geo_T[, 1], wdo_geo_T[, 2: 11], type = 'l', lty = 1, 
          xlab = 'Time relative to geoengineering start [yr]', 
          ylab = 'T anomaly [K]')
  matplot(wdo_geo_V[, 1], wdo_geo_V[, 2: 11], type = 'l', lty = 1,
          xlab = 'Time relative to geoengineering start [yr]', 
          ylab = 'Ice volume [m sle]')
  matplot(wdo_geo_Vdot[, 1], wdo_geo_Vdot[, 2: 11], type = 'l', lty = 1,
          xlab = 'Time relative to geoengineering start [yr]', 
          ylab = 'Rate of sea level rise [mm yr^-1]')
  dev.off()
  # Write the matrices to files.  
  geo_T_file = paste('../data_tables/geo_', run_tags[i], '(2006_3000)_T.csv', sep = '')
  geo_V_file = paste('../data_tables/geo_', run_tags[i], '(2006_3000)_V.csv', sep = '')
  geo_Vdot_file = paste('../data_tables/geo_', run_tags[i], '(2006_3000)_Vdot.csv', sep = '')
  wdo_geo_T_file = paste('../data_tables/window_geo_', run_tags[i], '_T.csv', sep = '')
  wdo_geo_V_file = paste('../data_tables/window_geo_', run_tags[i], '_V.csv', sep = '')
  wdo_geo_Vdot_file = paste('../data_tables/window_geo_', run_tags[i], '_Vdot.csv', sep = '')
  write.csv(geo_T, geo_T_file, row.names = FALSE)
  write.csv(geo_V, geo_V_file, row.names = FALSE)
  write.csv(geo_Vdot, geo_Vdot_file, row.names = FALSE)
  write.csv(wdo_geo_T, wdo_geo_T_file, row.names = FALSE)
  write.csv(wdo_geo_V, wdo_geo_V_file, row.names = FALSE)
  write.csv(wdo_geo_Vdot, wdo_geo_Vdot_file, row.names = FALSE)
  # Delete large matrices to save memory.  
  rm(geo_data)
}

