# final_geoeng_plots.R
# Patrick Applegate, patrick.applegate@psu.edu
# 
# Makes Figures 1-3 and S1-S3, plus Table S1, for Applegate and Keller (2015, 
# ERL).  See ../sem_test/sem_test_v5.R and ../searise/sensitivity_fig.R for 
# Figures 4 and 5.  

# Mise en place.  
rm(list = ls())
graphics.off()

# Set the working directory.  
# setwd('~/Documents/Work/Old_projects/AM/code_figures/')

# Get some necessary packages.  
require('RColorBrewer')
require('fields')
require('gridExtra')

# Set some values.  
geo_yr0 = seq(2025, 2475, 50)       # yr; vector of times when
                                    # AM starts
run_tags = c('equil', '0.1grad')
                                    # flags indicating the type
                                    # of AM scenario;
                                    # equil, temperatures level off
                                    # grad, temps decline gradually
                                    # zero, temps go to 0 instantly
proj_yr = c(2006, 3000)             # years over which projection
                                    # model output is used
wdo_yr = c(-29, 500)                # years over which to subsample
                                    # the projection model output,
                                    # relative to the year values
                                    # in geo_yr0
panel_labels = c('a', 'b', 'c', 'd', 'e', 'f')
                                    # labels for the different figure
                                    # panels

# Define some matrix dimensions.  
proj_nrow = proj_yr[2]- proj_yr[1]+ 1
wdo_nrow = wdo_yr[2]- wdo_yr[1]+ 1
n_yr0 = length(geo_yr0)
n_type = length(run_tags)

# Set up some colors.  
color = rev(brewer.pal(n_yr0, 'Spectral'))

# Read in and organize information from the data tables written by
# data_file_writer_v4.R.  
# Hindcast, 1900-2005
hind_T = read.csv('../data_tables/hindcast(1900_2005)_T.csv')
hind_V = read.csv('../data_tables/hindcast(1900_2005)_V.csv')
hind_Vdot = read.csv('../data_tables/hindcast(1900_2005)_Vdot.csv')
# RCP 8.5
rcp_T = read.csv('../data_tables/rcp8p5(2006_3000)_T.csv')
rcp_V = read.csv('../data_tables/rcp8p5(2006_3000)_V.csv')
rcp_Vdot = read.csv('../data_tables/rcp8p5(2006_3000)_Vdot.csv')
wdo_rcp_T = read.csv('../data_tables/window_rcp8p5_T.csv')[, 2: (n_yr0+ 1)]
wdo_rcp_V = read.csv('../data_tables/window_rcp8p5_V.csv')[, 2: (n_yr0+ 1)]
wdo_rcp_Vdot = read.csv('../data_tables/window_rcp8p5_Vdot.csv')[, 2: (n_yr0+ 1)]
# AM scenarios
geo_T = array(NA, dim = c(proj_nrow, n_yr0, n_type))
geo_V = array(NA, dim = c(proj_nrow, n_yr0, n_type))
geo_Vdot = array(NA, dim = c(proj_nrow, n_yr0, n_type))
wdo_geo_T = array(NA, dim = c(wdo_nrow, n_yr0, n_type))
wdo_geo_V = array(NA, dim = c(wdo_nrow, n_yr0, n_type))
wdo_geo_Vdot = array(NA, dim = c(wdo_nrow, n_yr0, n_type))
for (i in 1: n_type) {
  geo_T_file = paste('../data_tables/geo_', run_tags[i], 
                     '(2006_3000)_T.csv', sep = '')
  geo_V_file = paste('../data_tables/geo_', run_tags[i], 
                     '(2006_3000)_V.csv', sep = '')
  geo_Vdot_file = paste('../data_tables/geo_', run_tags[i], 
                        '(2006_3000)_Vdot.csv', sep = '')
  wdo_geo_T_file = paste('../data_tables/window_geo_', run_tags[i], 
                         '_T.csv', sep = '')
  wdo_geo_V_file = paste('../data_tables/window_geo_', run_tags[i], 
                         '_V.csv', sep = '')
  wdo_geo_Vdot_file = paste('../data_tables/window_geo_', run_tags[i], 
                            '_Vdot.csv', sep = '')
  geo_T[, , i] = as.matrix(read.csv(geo_T_file))[, 2: (n_yr0+ 1)]
  geo_V[, , i] = as.matrix(read.csv(geo_V_file))[, 2: (n_yr0+ 1)]
  geo_Vdot[, , i] = as.matrix(read.csv(geo_Vdot_file))[, 2: (n_yr0+ 1)]
  wdo_geo_T[, , i] = as.matrix(read.csv(wdo_geo_T_file))[, 2: (n_yr0+ 1)]
  wdo_geo_V[, , i] = as.matrix(read.csv(wdo_geo_V_file))[, 2: (n_yr0+ 1)]
  wdo_geo_Vdot[, , i] = as.matrix(read.csv(wdo_geo_Vdot_file))[, 2: (n_yr0+ 1)]
}

# Set up some plotting vectors.  
proj_t = rcp_T[, 1]
wdo_t = seq(wdo_yr[1], wdo_yr[2], by = 1)

# Because we're interested in ice volume loss, convert the volume
# arrays appropriately.  
V_0 = rcp_V[1, 2]
hind_V_loss = V_0- hind_V[, 2]
rcp_V_loss = V_0- rcp_V[, 2]
wdo_rcp_V_loss = V_0- wdo_rcp_V
geo_V_loss = V_0- geo_V
wdo_geo_V_loss = V_0- wdo_geo_V

# Calculate differences between the no-AM and AM
# cases.  
# diff_T, time-dependent temperature difference
diff_T = array(rcp_T[, 2], dim = c(proj_nrow, n_yr0, n_type))- geo_T
# cum_diff_T, running total of diff_T
cum_diff_T = apply(diff_T, c(2, 3), cumsum)
# diff_V, time-dependent ice volume difference
diff_V = geo_V- array(rcp_V[, 2], dim = c(proj_nrow, n_yr0, n_type))
# diff_Vdot, time-dependent rate of ice volume change difference
diff_Vdot = array(rcp_Vdot[, 2], dim = c(proj_nrow, n_yr0, n_type))- geo_Vdot
# diff_wdo_T, time-dependent difference in temperature over the window
diff_wdo_T = array(as.matrix(wdo_rcp_T), dim = c(wdo_nrow, n_yr0, n_type))- wdo_geo_T
# cum_diff_wdo_T, running total of diff_wdo_T
foo_diff_wdo_T = diff_wdo_T
foo_diff_wdo_T[is.na(foo_diff_wdo_T)] = 0
cum_diff_wdo_T = apply(foo_diff_wdo_T, c(2, 3), cumsum)
# diff_wdo_V, time-dependent ice volume difference over the window
diff_wdo_V = wdo_geo_V- array(as.matrix(wdo_rcp_V), dim = c(wdo_nrow, n_yr0, n_type))
# diff_wdo_Vdot, time-dependent rate of ice volume change difference
diff_wdo_Vdot = array(as.matrix(wdo_rcp_Vdot), dim = c(wdo_nrow, n_yr0, n_type))- wdo_geo_Vdot

# Find values of the quantities of interest just before 
# AM begins.  
row_0yr = which(wdo_t == 0)
pre_30yr = seq(row_0yr-29, row_0yr, by = 1)
geo_yr0_index = cbind(geo_yr0- proj_yr[1], seq(1, length(geo_yr0), by = 1), rep(1, length(geo_yr0)))
# temperature anomaly just before AM begins [K]
geo_T_yr0 = geo_T[geo_yr0_index]
# ice volume just before AM begins [m sle]
geo_V_yr0 = geo_V[geo_yr0_index]
# existing sea level contribution just before AM begins [m sle]
geo_V_loss_yr0 = V_0- geo_V[geo_yr0_index]
# rate of sea level rise just before AM begins [mm sle yr^-1]
geo_Vdot_yr0 = geo_Vdot[geo_yr0_index]
# mean rate of sea level rise in the 30 yr just before AM begins 
# [mm sle^-1]
geo_Vdot_pre_30yr = apply(wdo_geo_Vdot[pre_30yr, , 1], 2, mean, na.rm = TRUE)

# Calculate some metrics that involve the values calculated above.  
norm_diff_wdo_V = log10(diff_wdo_V[30: 530, , ]/ array(matrix(geo_V_loss_yr0, nrow = 501, ncol = n_yr0, byrow = TRUE), dim = c(501, n_yr0, n_type)))
norm_diff_wdo_Vdot = log10(diff_wdo_Vdot[30: 530, , ]/ array(matrix(geo_Vdot_pre_30yr, nrow = 501, ncol = n_yr0, byrow = TRUE), dim = c(501, n_yr0, n_type)))
addl_geo_V_loss = wdo_geo_V_loss[30: 530, , ]- array(matrix(geo_V_loss_yr0, nrow = 501, ncol = n_yr0, byrow = TRUE), dim = c(501, n_yr0, n_type))

# Figure 1: long-term inputs and outputs (Fig. 1 is the top two panels of this figure)
pdf('geoeng_fig1.pdf', width = 4.488, height = 6)
par(mfcol = c(3, 2), mar = c(4, 4, 2, 1), ps = 12.25)
for (i in 1: n_type) {
  # Top panel
  matplot(proj_t, geo_T[, , i], type = 'l', lty = 1, lwd = 1.5, col = color, xlim = c(1900, 3000), ylim = c(-2, max(rcp_T[, 2])), bty = 'n', xlab = 'Time [yr]', ylab = 'Greenland T anomaly [K]')
  lines(hind_T[, 1], hind_T[, 2], lwd = 0.75, col = 'darkgray')
  lines(rcp_T[, 1], rcp_T[, 2], lwd = 1.5, col = 'black')
  points(geo_yr0, geo_T_yr0, pch = 16, col = color)
  mtext(panel_labels[i], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  if (i == 1) {
    mtext('Temperature stabilization', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  } else {
    mtext('Temperature drawdown', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  }
  # Middle panel
  matplot(proj_t, geo_V_loss[, , i], type = 'l', lty = 1, lwd = 1.5, col = color, xlim = c(1900, 3000), ylim = c(0, max(rcp_V_loss)), bty = 'n', xlab = 'Time [yr]', ylab = 'SL contribution [m]')
  lines(hind_V[, 1], hind_V_loss, lwd = 0.75, col = 'darkgray')
  lines(rcp_V[, 1], rcp_V_loss, lwd = 1.5, col = 'black')
  points(geo_yr0, V_0- geo_V_yr0, pch = 16, col = color)
  mtext(panel_labels[i+ 2], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  # Bottom panel
  matplot(proj_t, geo_Vdot[, , i], type = 'l', lty = 1, lwd = 1.5, col = color, xlim = c(1900, 3000), ylim = c(min(geo_Vdot), max(geo_Vdot)), bty = 'n', xlab = 'Time [yr]', ylab = 'Rate of SL contribution [mm/yr]')
  lines(hind_V[, 1], hind_Vdot[, 2], lwd = 0.75, col = 'darkgray')
  lines(rcp_V[, 1], rcp_Vdot[, 2], lwd = 1.5, col = 'black')
  points(geo_yr0, geo_Vdot_yr0, pch = 16, col = color)
  mtext(panel_labels[i+ 4], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
}
dev.off()

# Figure 2: image plots with overlaid contours showing reductions in total sea 
# level and the rate of sea level rise.  NOTE, image.plot from the fields package
# messes up the arrangement of the figures -- need to swap the panel in the lower left
# and the upper right manually.  
pdf('geoeng_fig2.pdf', width = 4.488, height = 5)
par(mfcol = c(2, 2), mar = c(6, 3.5, 2, 0.7), ps = 10)
V_lim = c(0, ceiling(max(diff_wdo_V[30: 530, , ], na.rm = TRUE)))
Vdot_lim = c(0, ceiling(max(diff_wdo_Vdot[30: 530, , ], na.rm = TRUE)))
V_breaks = seq(round(V_lim[1], 1), round(V_lim[2], 1), length.out = ((round(V_lim[2], 1)- round(V_lim[1], 1))/ 0.5)+ 1)
Vdot_breaks = seq(floor(Vdot_lim[1]), round(Vdot_lim[2], 1), length.out = (round(Vdot_lim[2], 1)- floor(Vdot_lim[1]))+ 1)
for (i in 1: n_type) {
  # upper panel
  image.plot(x = wdo_t[30: 530], y = geo_yr0, z = diff_wdo_V[30: 530, , i], zlim = V_lim, col = terrain.colors(length(V_breaks)- 1), horizontal = TRUE, axis.args = list(at = V_breaks), xlab = 'Time after AM begins [yr]', ylab = 'Time when AM begins [yr]', legend.lab = 'Avoided SL rise [m]', mgp = c(2.5, 1, 0))
  contour(diff_wdo_V[30: 530, , i], add = TRUE, x = wdo_t[30: 530], y = geo_yr0, levels = seq(1, 6, by = 1), col = 'white')
  mtext(panel_labels[i], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.8, font = 2)
  if (i == 1) {
    mtext('Temperature stabilization', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  } else {
    mtext('Temperature drawdown', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  }
  # lower panel
  image.plot(x = wdo_t[30: 530], y = geo_yr0, z = diff_wdo_Vdot[30: 530, , i], zlim = Vdot_lim, col = terrain.colors(length(Vdot_breaks)- 1), horizontal = TRUE, axis.args = list(at = Vdot_breaks), xlab = 'Time after AM begins [yr]', ylab = 'Time when AM begins [yr]', legend.lab = 'Reduction in rate of SL contribution [m]', mgp = c(2.5, 1, 0))
  contour(diff_wdo_Vdot[30: 530, , i], add = TRUE, x = wdo_t[30: 530], y = geo_yr0, levels = seq(3, 12, by = 3), col = 'white')
  mtext(panel_labels[i+ 2], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.8, font = 2)
}
dev.off()

# Figure 3: Additional sea level rise that happens after AM begins.  NOTE, 
# image.plot produces weird results if the height of the pdf is reduced to 2.5 inches; 
# have to manually adjust the page extent afterward.  
pdf('geoeng_fig3.pdf', width = 4.488, height = 5)
par(mfcol = c(2, 2), mar = c(6, 3.5, 2, 0.7), ps = 10)
addl_V_loss_q = c(1, 0.1)
for (i in 1: n_type) {
  addl_V_loss_lim = c(0, ceiling(max(addl_geo_V_loss[, , i])/ addl_V_loss_q[i])* addl_V_loss_q[i])
  image.plot(x = wdo_t[30: 530], y = geo_yr0, z = addl_geo_V_loss[, , i], zlim = addl_V_loss_lim, col = terrain.colors(2* addl_V_loss_lim[2]/ addl_V_loss_q[i]), horizontal = TRUE, axis.args = NULL, xlab = 'Time after AM begins [yr]', ylab = 'Time when AM begins [yr]', legend.lab = 'Additional SL rise [m]', mgp = c(2.5, 1, 0))
  contour(addl_geo_V_loss[, , i], add = TRUE, x = wdo_t[30: 530], y = geo_yr0, levels = seq(0, addl_V_loss_lim[2], by = addl_V_loss_q[i]), col = 'white')
  mtext(panel_labels[i], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.8, font = 2)
  title('') # see http://stackoverflow.com/questions/12895783/r-language-mtext-not-working-with-image-plot-array
  if (i == 1) {
    mtext('Temperature stabilization', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  } else {
    mtext('Temperature drawdown', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  }
}
dev.off()

# Table S1: year when AM begins, temperature anomaly when AM begins, 
# ice volume when AM begins, and color of curves in Figures 1, 4, and S1-S3.  
table_S1 = as.data.frame(cbind(geo_yr0, round(geo_T_yr0, 2), round(geo_V_yr0, 2), color))
colnames(table_S1) = c('Year when AM begins', 'T anom when AM begins', 'V when AM begins', 'Color')
pdf('table_S1.pdf')
grid.table(table_S1)
dev.off()

# Figure S1: differences in long-term inputs and outputs between
# AM and no-AM cases 
pdf('geoeng_figS1.pdf', width = 4.488, height = 6)
par(mfcol = c(3, 2), mar = c(4, 4, 2, 1), ps = 12.25)
for (i in 1: n_type) {
  # Left panel
  matplot(proj_t, cum_diff_T[, , i], type = 'l', lty = 1, lwd = 2, col = color, xlim = c(1900, 3000), ylim = c(min(cum_diff_T), max(cum_diff_T)), bty = 'n', xlab = 'Time [yr]', ylab = 'Cumulative avoided T rise [K yr]')
  lines(hind_T[, 1], hind_T[, 2]- hind_T[, 2], lwd = 1, col = 'gray')
  lines(rcp_T[, 1], rcp_T[, 2]- rcp_T[, 2], lwd = 2, col = 'black')
  points(geo_yr0, geo_T_yr0- geo_T_yr0, pch = 16, col = color)
  mtext(panel_labels[i], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  if (i == 1) {
    mtext('Temperature stabilization', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  } else {
    mtext('Temperature drawdown', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  }
  # Middle panel
  matplot(proj_t, t(apply(diff_V[, , i], 1, rev)), type = 'l', lty = 1, lwd = 2, col = rev(color), xlim = c(1900, 3000), ylim = c(min(diff_V), max(diff_V)), bty = 'n', xlab = 'Time [yr]', ylab = 'Avoided SL contribution [m]')
  lines(hind_V[, 1], hind_V_loss- hind_V_loss, lwd = 1, col = 'gray')
  lines(rcp_V[, 1], rcp_V_loss- rcp_V_loss, lwd = 2, col = 'black')
  points(geo_yr0, geo_V_yr0- geo_V_yr0, pch = 16, col = color)
  mtext(panel_labels[i+ 2], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  # Right panel
  matplot(proj_t, t(apply(diff_Vdot[, , i], 1, rev)), type = 'l', lty = 1, lwd = 2, col = rev(color), xlim = c(1900, 3000), ylim = c(min(diff_Vdot), max(diff_Vdot)), bty = 'n', xlab = 'Time [yr]', ylab = 'Reduction in rate of SL contribution [mm/yr]')
  lines(hind_V[, 1], hind_Vdot[, 2]- hind_Vdot[, 2], lwd = 1, col = 'gray')
  lines(rcp_V[, 1], rcp_Vdot[, 2]- rcp_Vdot[, 2], lwd = 2, col = 'black')
  points(geo_yr0, geo_Vdot_yr0- geo_Vdot_yr0, pch = 16, col = color)
  mtext(panel_labels[i+ 4], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
}
dev.off()

# Figure S2: epoch inputs and outputs (3 panels tall by 3 panels wide)
pdf('geoeng_figS2.pdf', width = 4.488, height = 6)
par(mfcol = c(3, 2), mar = c(4, 4, 2, 1), ps = 12.25)
for (i in 1: n_type) {
  # Left panel
  matplot(wdo_t, wdo_rcp_T, type = 'l', lty = 2, lwd = 1, col = color, xlim = wdo_yr, ylim = c(min(wdo_geo_T, na.rm = TRUE), max(wdo_geo_T, na.rm = TRUE)), bty = 'n', xlab = 'Time [yr]', ylab = 'Greenland T anomaly [K]')
  matlines(wdo_t, wdo_geo_T[, , i], type = 'l', lty = 1, lwd = 2, col = color)
  mtext(panel_labels[i], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  if (i == 1) {
    mtext('Temperature stabilization', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  } else {
    mtext('Temperature drawdown', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  }
  # Middle panel
  matplot(wdo_t, wdo_rcp_V_loss, type = 'l', lty = 2, lwd = 1, col = color, xlim = wdo_yr, ylim = c(min(wdo_geo_V_loss, na.rm = TRUE), max(wdo_geo_V_loss, na.rm = TRUE)), bty = 'n', xlab = 'Time [yr]', ylab = 'SL contribution [m]')
  matlines(wdo_t, wdo_geo_V_loss[, , i], type = 'l', lty = 1, lwd = 2, col = color)
  mtext(panel_labels[i+ 2], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  # Right panel
  matplot(wdo_t, wdo_rcp_Vdot, type = 'l', lty = 2, lwd = 1, col = color, xlim = wdo_yr, ylim = c(min(wdo_geo_Vdot, na.rm = TRUE), max(wdo_geo_Vdot, na.rm = TRUE)), bty = 'n', xlab = 'Time [yr]', ylab = 'Rate of SL contribution [mm/yr]')
  matlines(wdo_t, wdo_geo_Vdot[, , i], type = 'l', lty = 1, lwd = 2, col = color)
  mtext(panel_labels[i+ 4], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
}
dev.off()

# Figure S3: epoch differences (3 panels tall by 3 panels wide)
pdf('geoeng_figS3.pdf', width = 4.488, height = 6)
par(mfcol = c(3, 2), mar = c(4, 4, 2, 1), ps = 12.25)
for (i in 1: n_type) {
  # Top panel
  matplot(wdo_t, cum_diff_wdo_T[, , i], type = 'l', lty = 1, lwd = 2, col = color, xlim = wdo_yr, ylim = c(min(cum_diff_wdo_T, na.rm = TRUE), max(cum_diff_wdo_T, na.rm = TRUE)), bty = 'n', xlab = 'Time after AM begins [yr]', ylab = 'Cumulative avoided T rise [K yr]')
  mtext(panel_labels[i], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  if (i == 1) {
    mtext('Temperature stabilization', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  } else {
    mtext('Temperature drawdown', line = 1.0, outer = FALSE, cex = 0.7, font = 2)
  }
  # Middle panel
  matplot(wdo_t, diff_wdo_V[, , i], type = 'l', lty = 1, lwd = 2, col = color, xlim = wdo_yr, ylim = c(min(diff_wdo_V, na.rm = TRUE), max(diff_wdo_V, na.rm = TRUE)), bty = 'n', xlab = 'Time after AM begins [yr]', ylab = 'Avoided SL contribution [m]')
  mtext(panel_labels[i+ 2], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
  # Bottom panel
  matplot(wdo_t, diff_wdo_Vdot[, , i], type = 'l', lty = 1, lwd = 2, col = color, xlim = wdo_yr, ylim = c(min(diff_wdo_Vdot, na.rm = TRUE), max(diff_wdo_Vdot, na.rm = TRUE)), bty = 'n', xlab = 'Time after AM begins [yr]', ylab = 'Reduction in rate of SL contribution [mm/yr]')
  mtext(panel_labels[i+ 4], side = 3, line = -1, at = par('usr')[1]+ 0.06* (par('usr')[2]- par('usr')[1]), cex = 0.7, font = 2)
}
dev.off()

# Extra pieces for Figures 2, 3, and S5, representing places where the variable
# of interest becomes 0 or less, and thus causes representations of the data that 
# truncate at 0, and log transformations, to barf.  
pdf('extra_fig_pieces.pdf', width = 4.488, height = 5)
par(mfrow = c(2, 2))
image(diff_wdo_V[30: 530, , 1] <= 0, col = c('transparent', 'gray'), main = 'Fig. 2a')
image(diff_wdo_Vdot[30: 530, , 1] <= 0, col = c('transparent', 'gray'), main = 'Fig. 2c')
image(addl_geo_V_loss[, , 2] <= 0, col = c('transparent', 'gray'), main = 'Fig. 3b')
dev.off()

# figure for Reviewer #1
pdf('reviewer_figure.pdf', width = 4.488, height = 2.5)
par(mfrow = c(1, 2), cex = 0.66)
matplot(geo_T[, , 1], geo_V[, , 1], type = 'l', col = color, lty = 1, lwd = 1.5, main = 'Temperature stabilization', xlab = 'Temperature anomaly [K]', ylab = 'Ice volume [m sle]', bty = 'n')
lines(rcp_T[, 2], rcp_V[, 2], lwd = 1.5, col = 'black')
points(geo_T_yr0, geo_V_yr0, pch = 16, col = color)
matplot(geo_T[, , 2], geo_V[, , 2], type = 'l', col = color, lty = 1, lwd = 1.5, main = 'Temperature drawdown',  xlab = 'Temperature anomaly [K]', ylab = 'Ice volume [m sle]', bty = 'n')
lines(rcp_T[, 2], rcp_V[, 2], lwd = 1.5, col = 'black')
points(geo_T_yr0, geo_V_yr0, pch = 16, col = color)
dev.off()