# read_ser.R
# Patrick Applegate, patrick.applegate@psu.edu
# 
# Converts SICOPOLIS .ser files into data frames that can be
# conveniently manipulated in R.  
# 
# Names of columns in the resulting data frame and their meanings: 
# 1. t          ka; elapsed time
# 2. D_Ts  	    deg. C; surface temperature anomaly (forcing)
# 3. z_sl		    m; sea level (forcing)
# 
# 4. H_max		  m; maximum ice thickness
# 5. zs_max	    m; maximum ice elevation
# 6. V_g		    10^ 6 km^ 3; total ice volume (note units!)
# 7. V_t		    km^ 3; volume of temperate ice (note units!)
# 8. V_fw		    km^ 3/ yr; volume of freshwater produced by melting and calving
# 9. z_sle		  m; sea level equivalent of ice volume (on land?)  
# 
# 10. Aib		    10^ 6 km^ 2; ice-covered area
# 11. Atb		    10^ 6 km^ 2; area covered by temperate ice
# 12. V_bm		  km^ 3/ yr; water drainage due to basal melting
# 13. V_tld	    km^ 3/ yr; water drainage from the temperate ice
# 14. H_t_max   m; maximum thickness of the temperate ice
# 15. vs_max	  m/ yr; maximum surface velocity

read_ser <- function(filename) {

# Set some values.  
n_var = 15  # number of variables in the .ser files
var_names = c("t", "D_Ts", "z_sl", "H_max", "zs_max", "V_g", "V_t", "V_fw", "z_sle", "Aib", "Atb", "V_bm", "V_tld", "H_t_max", "vs_max")
            # names of the variables corresponding to the list above

# Read in the .ser file and determine how many time steps it contains.  
foo = read.table(filename, fill = TRUE, skip = 4)
n_step = length(foo[, 1])/ 3

output = data.frame(array(dim = c(n_step, n_var)))
colnames(output) = var_names

for (i in 1: n_step) {
    output[i, 1: 3] = as.vector(foo[(3* (i- 1)+ 1), 1: 3])
    output[i, 4: 9] = foo[(3* (i- 1)+ 2), 1: 6]
    output[i, 10: 15] = foo[(3* (i- 1)+ 3), 1: 6]
}

return(output)

} # end read_ser.R