# sensitivity_fig.R
# Patrick Applegate, patrick.applegate@psu.edu
# 
# Generates Figure 5 from the manuscript, based on digitized results from 
# Bindschadler et al (2013, their Fig. 15a) and SICOPOLIS runs following RCP 8.5
# and using the same parameter combinations as in Applegate et al (2012).  

# Mise en place.  
rm(list = ls())
graphics.off()

# Get a needed package.  
require('RColorBrewer')

# Set the working directory.  
# setwd('/Users/Nordenskjold/Documents/Work/geoengineering/code_figures')

# Which runs satisfied the within-10%-of-modern-ice-volume constraint?  
good.runs <- c(3, 7, 8, 15, 18, 19, 23, 29, 30, 40, 43, 45, 46, 47, 49, 51, 53, 60, 66, 67, 70, 78, 82, 87, 88, 89, 92)

# Which run gave the best estimate of the modern ice volume?  
best.run <- 29

# Read in data from the seaRISE project (digitized from Bindschadler et al.,
# their Fig. 15a); arranged as years, ice volume loss (in funky units; 10^14
# m^3), and model (1, ISSM; 2, SICOPOLIS; 3, AIF1a; 4, IcIES; 5, UMISM)
searise.data <- as.matrix(read.csv('searise_data_v2.csv', header = FALSE))

# Read in data from previous SICOPOLIS runs following RCP 8.5.  
data <- as.matrix(read.csv('icevol(t)_RCP8p5.csv', header = FALSE))

# Convert the seaRISE results into sensible units (see Bindschadler et al 2013, 
# their p. 202).  
searise.data[, 1] <- searise.data[, 1]+ 2000
searise.data[, 2] <- searise.data[, 2]/ -4

# Extract useful information from the SICOPOLIS data table.  
time <- data[, 1]
icevols <- data[, 2: 101]

# Set some colors.  
colors <- brewer.pal(5, 'Set1')

# Calculate the change in ice volumes relative to the first time step.  
delta.icevol <- matrix(icevols[1, ], nrow = 496, ncol = 100, byrow = TRUE)- icevols[, ]

# Make a figure.  
pdf('geoeng_fig5.pdf', width = 4, height = 4)
matplot(time, delta.icevol, type = 'l', lty = 1, col = 'gray', bty = 'n', xlab = 'Time [yr]', ylab = 'SL contribution [m]')
matlines(time, delta.icevol[, good.runs], lty = 1, col = 'blue')
points(searise.data[, 1], searise.data[, 2], col = colors[searise.data[, 3]], pch = 16)
lines(time, delta.icevol[, best.run], lty = 1, lwd = 3, col = 'black')
legend('topleft', legend = c('ISSM', 'SICOPOLIS', 'AIF1a', 'IcIES', 'UMISM'), pch = 16, col = colors, bty = 'n')
dev.off()