# temp_curve_writer.R
# Patrick Applegate, patrick.applegate@psu.edu
# 
# Generates temperature curves for the geoengineering model runs based on Jacob 
# Schewe's results for the RCP8.5 emissions scenario with the Climber 3-alpha
# intermediate-complexity model.  Makes a quick plot of the resulting
# temperature curves and creates a series of .dat files that contain the 
# temperature curves in a format that SICOPOLIS can use.  In the file names,
# *grad0.1*.dat indicate gradual decline scenarios, and *equil*.dat indicate 
# equilibration scenarios.  

# Mise en place.  
rm(list = ls())
graphics.off()

# Load some packages.  
require('RColorBrewer')

# Read in the temperature curve for Jacob's Climber 3 alpha run.  
schewe_8p5 = read.table("temp_curve_RCP8p5_1950to2500.dat")

# Set the years in which AM begins.  
geo_start_yr = seq(2025, 2475, 50)

# What slope should we use for the gradual decline AM scenarios? (K/ yr)
m = 0.1

# Set up a vector of years.  
yr = seq(1950, 3500, 1)

# Set up some colors.  
color = rev(brewer.pal(length(geo_start_yr), 'Spectral'))

# control run -- continue the final temperature anomaly 
# from Schewe's Climber 3 alpha runs to the end of the
# model run
control = array(dim = c(length(yr), 3))
control[, 2] = yr
control[1: length(schewe_8p5[, 1]), 3] = schewe_8p5[, 2]
control[(length(schewe_8p5[, 1])+ 1): length(yr), 3] = schewe_8p5[length(schewe_8p5[, 1]), 2]
control[, 3] = round(control[, 3], 3)
write("#     1950    1   3500", file = "temp_curve_rcp8p5_1950to3500.dat")
write.table(control, file = "temp_curve_RCP8p5_1950to3500.dat", append = TRUE, na = "", sep = "    ", row.names = FALSE, col.names = FALSE)
plot(yr, control[, 3], typ = "l", col = "black", xlab = "Time (yr)", ylab = "Greenland mean annual temperature anomaly (K)", xlim = c(2000, 3500))

# Set up the other curves.  
for (i in 1: length(geo_start_yr)) {
  file_name = paste("temp_curve_RCP8p5_equil", geo_start_yr[i], "_1950to3500.dat", sep = "")
  row_end = geo_start_yr[i]- schewe_8p5[1, 1]
  equil = array(dim = c(length(yr), 3))
  equil[, 2] = yr
  equil[1: row_end, 3] = schewe_8p5[1: row_end, 2]
  equil[(row_end+ 1): length(yr), 3] = schewe_8p5[row_end, 2]
  equil[, 3] = round(equil[, 3], 3)
  write("#     1950    1   3500", file = file_name)
  write.table(equil, file = file_name, append = TRUE, na = "", sep = "    ", row.names = FALSE, col.names = FALSE)
  lines(yr, equil[, 3], col = color[i])
  for (j in 1: length(m)) {
    file_name = paste("temp_curve_RCP8p5_", m, "grad", geo_start_yr[i], "_1950to3500.dat", sep = "")
    row_end = geo_start_yr[i]- schewe_8p5[1, 1]
    grad = array(dim = c(length(yr), 3))
    grad[, 2] = yr
    grad[1: row_end, 3] = schewe_8p5[1: row_end, 2]
    grad[(row_end+ 1): length(yr), 3] = schewe_8p5[row_end, 2]+ seq(from = -m, by = -m, length.out = (length(yr)- row_end))
    grad[seq(1, length(grad[, 2])) > row_end & grad[, 3] < 0, 3] = 0
    grad[, 3] = round(grad[, 3], 3)
    write("#     1950    1   3500", file = file_name)
    write.table(grad, file = file_name, append = TRUE, na = "", sep = "    ", row.names = FALSE, col.names = FALSE)
    lines(yr, grad[, 3], col = color[i])
  }
#   file_name = paste("temp_curve_RCP8p5_zero", geo_start_yr[i], "_1950to3500.dat", sep = "")
#   zero = array(dim = c(length(yr), 3))
#   zero[, 2] = yr
#   zero[1: row_end, 3] = schewe_8p5[1: row_end, 2]
#   zero[(row_end+ 1): length(yr), 3] = 0
#   zero[, 3] = round(zero[, 3], 3)
#   write("#     1950    1   3500", file = file_name)
#   write.table(zero, file = file_name, append = TRUE, na = "", sep = "    ", row.names = FALSE, col.names = FALSE)
#   lines(yr, zero[, 3], col = color[i])
}